TestOptions

Struct TestOptions 

pub struct TestOptions { /* private fields */ }
Options used by the macro-free test runtime wrappers.

Implementations

Source

impl TestOptions

pub fn new(name: impl Into<String>) -> Self

Creates options for a test with the given display name.

pub fn inferred() -> Self

Infers options from the current cargo-test thread name.

pub fn from_params(params: StartTestCaseParams) -> Self

Creates options from low-level lifecycle start parameters.

pub fn with_full_name(self, full_name: impl Into<String>) -> Self

Sets the test full name.

pub fn with_history_id(self, history_id: impl Into<String>) -> Self

Sets an explicit history identifier.

pub fn with_test_case_id(self, test_case_id: impl Into<String>) -> Self

Sets an explicit test case identifier.

pub fn with_description(self, description: impl Into<String>) -> Self

Sets the markdown description.

pub fn with_description_html(self, description: impl Into<String>) -> Self

Sets the HTML description.

pub fn with_label( self, name: impl Into<String>, value: impl Into<String>, ) -> Self

Adds an initial label.

pub fn with_allure_id(self, value: impl Into<String>) -> Self

Adds an initial Allure ID label.

pub fn with_manifest_dir(self, manifest_dir: impl Into<String>) -> Self

Sets the Cargo manifest directory used for package metadata lookup.

pub fn with_module_path(self, module_path: impl Into<String>) -> Self

Sets the Rust module path used for package metadata lookup.

pub fn with_title_path<I, V>(self, title_path: I) -> Self
where I: IntoIterator<Item = V>, V: Into<String>,

Sets the title path.

pub fn with_source( self, file: impl AsRef<str>, manifest_dir: impl Into<String>, module_path: impl Into<String>, ) -> Self

Sets source-location metadata used for title path and package metadata labels.

pub fn with_framework(self, framework: impl Into<String>) -> Self

Sets the framework label value.

pub fn without_framework(self) -> Self

Disables the framework label.

pub fn without_synthetic_suite_labels(self) -> Self

Disables synthetic suite labels.

pub fn with_panic_status(self, status: Status) -> Self

Sets the status to use for unclassified panics.