pub struct StartTestCaseParams {Show 18 fields
pub uuid: Option<String>,
pub name: String,
pub full_name: Option<String>,
pub history_id: Option<String>,
pub test_case_id: Option<String>,
pub description: Option<String>,
pub description_html: Option<String>,
pub status: Option<Status>,
pub status_details: Option<StatusDetails>,
pub stage: Option<Stage>,
pub labels: Vec<Label>,
pub links: Vec<Link>,
pub parameters: Vec<Parameter>,
pub steps: Vec<StepResult>,
pub attachments: Vec<Attachment>,
pub title_path: Option<Vec<String>>,
pub start: Option<i64>,
pub stop: Option<i64>,
}Expand description
Parameters used to start a test case.
Fields
uuid: Option<String>Optional explicit test UUID.
name: StringTest display name.
full_name: Option<String>Stable fully qualified test name.
history_id: Option<String>Optional explicit history identifier.
test_case_id: Option<String>Optional explicit logical test case identifier.
description: Option<String>Markdown description.
description_html: Option<String>HTML description.
status: Option<Status>Initial status.
status_details: Option<StatusDetails>Initial status details.
stage: Option<Stage>Initial lifecycle stage.
labels: Vec<Label>Initial labels.
links: Vec<Link>Initial links.
parameters: Vec<Parameter>Initial parameters.
steps: Vec<StepResult>Initial steps.
attachments: Vec<Attachment>Initial attachments.
title_path: Option<Vec<String>>Optional title path.
start: Option<i64>Optional start timestamp in milliseconds since the Unix epoch.
stop: Option<i64>Optional stop timestamp in milliseconds since the Unix epoch.
Implementations